@@ -25,7 +25,7 @@
 #pod =for :those General topics like getting source, building, installing, bug reporting and some
 #pod others are covered in the F<README>.
 #pod
-#pod =for test_synopsis my $v;
+#pod =for test_synopsis my ( $v, $bool );
 #pod
 #pod =head1 SYNOPSIS
 #pod
@@ -37,11 +37,9 @@
 #pod     $v = qv( v1.0.2.5 );    # v1.0.2.5
 #pod
 #pod     # Release status:
-#pod     if ( $v->is_trial ) {   # If the second part is odd.
-#pod         ...
-#pod     };
+#pod     $bool = $v->is_trial;   # true if the second part is odd.
 #pod
-#pod     # Other methods are inherited from Version::Dotted.
+#pod     # See Version::Dotted for other methods.
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -61,16 +59,17 @@
 #pod
 #pod =item *
 #pod
-#pod The second part defines the release status: odd numbers denotes a trial release.
+#pod The second part defines the release status: odd number denotes a trial release.
 #pod
 #pod     $v = qv( v1.0 );        # $v == v1.0.0
 #pod     $v->is_trial;           # false
 #pod     $v->bump( 1 );          # $v == v1.1.0
 #pod     $v->is_trial;           # true
 #pod
+#pod Such versioning scheme was used by Linux kernel (between 1.0 and 2.6) and still used by Perl.
+#pod
 #pod =back
 #pod
-#pod Such versioning scheme was used by Linux kernel (between 1.0 and 2.6) and still used by Perl.
 #pod
 #pod =cut
 
@@ -79,18 +78,37 @@ package Version::Dotted::Odd;
 use strict;
 use warnings;
 
-# ABSTRACT: Use odd/even versioning scheme in your Perl modules
-our $VERSION = 'v0.0.0_06'; # TRIAL VERSION
+# ABSTRACT: Odd/even versioning scheme
+our $VERSION = 'v0.0.0_07'; # TRIAL VERSION
 
 use parent 'Version::Dotted';
 
-sub _min_len { 3 };     ## no critic ( ProhibitUnusedPrivateSubroutines, RequireFinalReturn )
+# --------------------------------------------------------------------------------------------------
+
+#pod =Attribute min_len
+#pod
+#pod Minimal number of parts, read-only.
+#pod
+#pod     $int = Version::Dotted::Odd->min_len;   # == 3
+#pod
+#pod C<Version::Dotted::Odd> objects always have at least 3 parts.
+#pod
+#pod =cut
+
+sub min_len { 3 };           ## no critic ( RequireFinalReturn )
 
 # --------------------------------------------------------------------------------------------------
 
 #pod =method is_trial
 #pod
-#pod Returns true if the second version part is an odd number, and false otherwise.
+#pod Returns true in case of trial version, and false otherwise.
+#pod
+#pod     $bool = $v->is_trial;
+#pod
+#pod A version is considered trial if the second part is an odd number:
+#pod
+#pod     qv( v1.1.3 )->is_trial;     # true
+#pod     qv( v1.2.0 )->is_trial;     # false
 #pod
 #pod =cut
 
@@ -110,6 +128,7 @@ sub is_trial {
 #pod
 #pod =for :list
 #pod = L<Version::Dotted>
+#pod = L<Odd-numbered versions for development releases|https://en.wikipedia.org/wiki/Software_versioning#Odd-numbered_versions_for_development_releases>
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
@@ -136,8 +155,8 @@ sub is_trial {
 #pod
 #pod =head1 WHAT?
 #pod
-#pod C<Version::Dotted> and its subclasses complement standard C<version> class with version
-#pod modification operations, which can be useful in distribution release tools.
+#pod C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
+#pod (re)define trial versions differently.
 #pod
 #pod =cut
 
@@ -154,17 +173,17 @@ __END__
 
 =head1 NAME
 
-Version::Dotted::Odd - Use odd/even versioning scheme in your Perl modules
+Version::Dotted::Odd - Odd/even versioning scheme
 
 =head1 VERSION
 
-Version v0.0.0_06, released on 2016-12-30 00:11 UTC.
+Version v0.0.0_07, released on 2017-01-03 22:12 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
 
-C<Version::Dotted> and its subclasses complement standard C<version> class with version
-modification operations, which can be useful in distribution release tools.
+C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
+(re)define trial versions differently.
 
 This is C<Version::Dotted::Odd> module/class documentation. However, read
 C<Version::Dotted> module/class documentation first, since it contains many relevant details.
@@ -172,7 +191,7 @@ C<Version::Dotted> module/class documentation first, since it contains many rele
 General topics like getting source, building, installing, bug reporting and some
 others are covered in the F<README>.
 
-=for test_synopsis my $v;
+=for test_synopsis my ( $v, $bool );
 
 =head1 SYNOPSIS
 
@@ -184,11 +203,9 @@ others are covered in the F<README>.
     $v = qv( v1.0.2.5 );    # v1.0.2.5
 
     # Release status:
-    if ( $v->is_trial ) {   # If the second part is odd.
-        ...
-    };
+    $bool = $v->is_trial;   # true if the second part is odd.
 
-    # Other methods are inherited from Version::Dotted.
+    # See Version::Dotted for other methods.
 
 =head1 DESCRIPTION
 
@@ -208,22 +225,39 @@ Version object always has at least 3 parts.
 
 =item *
 
-The second part defines the release status: odd numbers denotes a trial release.
+The second part defines the release status: odd number denotes a trial release.
 
     $v = qv( v1.0 );        # $v == v1.0.0
     $v->is_trial;           # false
     $v->bump( 1 );          # $v == v1.1.0
     $v->is_trial;           # true
 
+Such versioning scheme was used by Linux kernel (between 1.0 and 2.6) and still used by Perl.
+
 =back
 
-Such versioning scheme was used by Linux kernel (between 1.0 and 2.6) and still used by Perl.
+=head1 CLASS ATTRIBUTES
+
+=head2 min_len
+
+Minimal number of parts, read-only.
+
+    $int = Version::Dotted::Odd->min_len;   # == 3
+
+C<Version::Dotted::Odd> objects always have at least 3 parts.
 
 =head1 OBJECT METHODS
 
 =head2 is_trial
 
-Returns true if the second version part is an odd number, and false otherwise.
+Returns true in case of trial version, and false otherwise.
+
+    $bool = $v->is_trial;
+
+A version is considered trial if the second part is an odd number:
+
+    qv( v1.1.3 )->is_trial;     # true
+    qv( v1.2.0 )->is_trial;     # false
 
 =head1 SEE ALSO
 
@@ -231,6 +265,8 @@ Returns true if the second version part is an odd number, and false otherwise.
 
 =item L<Version::Dotted>
 
+=item L<Odd-numbered versions for development releases|https://en.wikipedia.org/wiki/Software_versioning#Odd-numbered_versions_for_development_releases>
+
 =back
 
 =head1 AUTHOR
