@@ -28,7 +28,9 @@
 #pod =for :those General topics like getting source, building, installing, bug reporting and some
 #pod others are covered in the F<README>.
 #pod
-#pod =for test_synopsis my ( $v, $int );
+#pod =for test_synopsis my ( $v, $int, $bool );
+#pod
+#pod =for comment ---------------------------------------------------------------------------------------
 #pod
 #pod =head1 SYNOPSIS
 #pod
@@ -37,8 +39,8 @@
 #pod
 #pod     # Construct:
 #pod     $v = Version::Dotted::Semantic->new( v1 );  # v1.0.0 (at least 3 parts)
-#pod     $v = qv( v1 );                  # v1.0.0 (at least 3 parts)
-#pod     $v = qv( 'v1.2.3.4' );          # v1.2.3.4
+#pod     $v = qv( v1 );                              # ditto
+#pod     $v = qv( 'v1.2.3.4' );                      # v1.2.3.4
 #pod
 #pod     # Get parts by name (indexing also works):
 #pod     $int = $v->part( 'major' );     # Always defined.
@@ -50,18 +52,18 @@
 #pod     $int = $v->patch;       # ditto
 #pod     $int = $v->trial;       # May be undefined.
 #pod
-#pod     # Bump the version by name (indexing also works):
+#pod     # Bump the version (indexing also works):
 #pod     $v->bump( 'trial' );    # Bump trial part.
 #pod     $v->bump( 'patch' );    # Bump patch and drop trial.
 #pod     $v->bump( 'minor' );    # Bump minor, reset patch and drop trial.
 #pod     $v->bump( 'major' );    # Bump major, reset minor and patch, drop trial.
 #pod
 #pod     # Release status:
-#pod     if ( $v->is_trial ) {   # If version has more than 3 parts.
-#pod         ...
-#pod     };
+#pod     $bool = $v->is_trial;   # true if version has more than 3 parts.
 #pod
-#pod     # Other methods are inherited from Version::Dotted.
+#pod     # See Version::Dotted for other methods.
+#pod
+#pod =for comment ---------------------------------------------------------------------------------------
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -81,12 +83,12 @@
 #pod
 #pod =item *
 #pod
-#pod First four parts have individual names:
+#pod First four parts have individual names.
 #pod
-#pod     $v->part( 0 ) == $v->part( 'major' ) == $v->major;
-#pod     $v->part( 1 ) == $v->part( 'minor' ) == $v->minor;
-#pod     $v->part( 2 ) == $v->part( 'patch' ) == $v->patch;
-#pod     $v->part( 3 ) == $v->part( 'trial' ) == $v->trial;
+#pod     $v->major = $v->part( 'major' );    # == $v->part( 0 );
+#pod     $v->minor = $v->part( 'minor' );    # == $v->part( 1 );
+#pod     $v->patch = $v->part( 'patch' );    # == $v->part( 2 );
+#pod     $v->trial = $v->part( 'trial' );    # == $v->part( 3 );
 #pod
 #pod     $v->bump( 'trial' );  # the same as $v->bump( 3 );
 #pod
@@ -101,14 +103,18 @@
 #pod
 #pod =back
 #pod
+#pod =for comment ---------------------------------------------------------------------------------------
+#pod
 #pod =head1 SEMANTIC VERSIONING
 #pod
 #pod See L<Semantic Versioning 2.0.0|http://semver.org/spec/v2.0.0.html>. It sound very reasonable to
 #pod me.
 #pod
-#pod Unfortunately, Semantic Versioning cannot be applied to Perl modules due to wider character set
-#pod (letters, hyphens, plus signs, e. g. 1.0.0-alpha.3+8daebec8a8e1) and specific precedence rules
-#pod (1.0.0-alpha < 1.0.0).
+#pod Unfortunately, Semantic Versioning cannot be applied to Perl modules (maintaining compatibility
+#pod with C<version> objects) due to wider character set (letters, hyphens, plus signs, e. g.
+#pod 1.0.0-alpha.3+8daebec8a8e1) and specific precedence rules (1.0.0-alpha < 1.0.0).
+#pod
+#pod =for comment ---------------------------------------------------------------------------------------
 #pod
 #pod =head1 DOTTED SEMANTIC VERSIONING
 #pod
@@ -224,6 +230,8 @@
 #pod L<Semantic Versioning 2.0.0|http://semver.org/spec/v2.0.0.html> is authored by L<Tom
 #pod Preston-Werner|http://tom.preston-werner.com/>, inventor of Gravatars and cofounder of GitHub.
 #pod
+#pod =for comment ---------------------------------------------------------------------------------------
+#pod
 #pod =head1 ADAPTATION DETAILS
 #pod
 #pod Paragraphs 1..8 of Semantic Versioning define I<normal> version number and establish rules for
@@ -286,15 +294,28 @@ package Version::Dotted::Semantic;
 use strict;
 use warnings;
 
-# ABSTRACT: Use Semantic Versioning for your Perl modules
-our $VERSION = 'v0.0.0_06'; # TRIAL VERSION
+# ABSTRACT: (Adapted) Semantic Versioning
+our $VERSION = 'v0.0.0_07'; # TRIAL VERSION
 
 use parent 'Version::Dotted';
 
 use Scalar::Util qw{};
 
-sub _min_len { 3 };     ## no critic ( ProhibitUnusedPrivateSubroutines, RequireFinalReturn )
-#~ sub _max_len { 4 };     ## no critic ( ProhibitUnusedPrivateSubroutines, RequireFinalReturn )
+# --------------------------------------------------------------------------------------------------
+
+#pod =Attribute min_len
+#pod
+#pod Minimal number of parts, read-only.
+#pod
+#pod     $int = Version::Dotted::Semantic->min_len;  # == 3
+#pod
+#pod C<Version::Dotted::Semantic> objects always have at least 3 parts.
+#pod
+#pod =cut
+
+sub min_len { 3 };           ## no critic ( RequireFinalReturn )
+
+# --------------------------------------------------------------------------------------------------
 
 my $names = {
     major => 0,
@@ -311,11 +332,11 @@ my $names = {
 #pod
 #pod =method patch
 #pod
-#pod Returns the first, second, and third part of the version, respectively.
+#pod Returns the first, the second, and the third part of the version, respectively.
 #pod
-#pod     $v->major;  # the first part
-#pod     $v->minor;  # the second part
-#pod     $v->patch;  # the third part
+#pod     $int = $v->major;   # the first part
+#pod     $int = $v->minor;   # the second part
+#pod     $int = $v->patch;   # the third part
 #pod
 #pod Since version always has at least 3 parts, these methods never return C<undef>.
 #pod
@@ -323,7 +344,7 @@ my $names = {
 #pod
 #pod Returns the fourth part of the version.
 #pod
-#pod     $v->trial;  # the fourth part
+#pod     $int = $v->trial;   # the fourth part
 #pod
 #pod The method returns C<undef> if version has less than 4 parts.
 #pod
@@ -360,14 +381,14 @@ for my $name ( qw{ part bump } ) {
 
 #pod =method is_trial
 #pod
-#pod Returns true (C<1>) if version has more than 3 parts, and false (C<undef>) otherwise.
+#pod Returns true in case of trial version, and false otherwise.
 #pod
-#pod If version has no more than 4 parts, C<is_trial> is equal to evaluating C<trial> in boolean
-#pod context. However, if version has more than 4 parts, it is not always true:
+#pod     $bool = $v->is_trial;
 #pod
-#pod     $v = Version::Dotted::Semantic( v1.2.3.0.5 );
-#pod     $v->trial;      # false (0)
-#pod     $v->is_trial;   # true
+#pod A version is considered trial if it has more than 3 parts:
+#pod
+#pod     qv( v1.2.3.4 )->is_trial;   # true
+#pod     qv( v1.2.4   )->is_trial;   # false
 #pod
 #pod =cut
 
@@ -423,8 +444,8 @@ sub is_trial {
 #pod
 #pod =head1 WHAT?
 #pod
-#pod C<Version::Dotted> and its subclasses complement standard C<version> class with version
-#pod modification operations, which can be useful in distribution release tools.
+#pod C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
+#pod (re)define trial versions differently.
 #pod
 #pod =cut
 
@@ -441,17 +462,17 @@ __END__
 
 =head1 NAME
 
-Version::Dotted::Semantic - Use Semantic Versioning for your Perl modules
+Version::Dotted::Semantic - (Adapted) Semantic Versioning
 
 =head1 VERSION
 
-Version v0.0.0_06, released on 2016-12-30 00:11 UTC.
+Version v0.0.0_07, released on 2017-01-03 22:12 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
 
-C<Version::Dotted> and its subclasses complement standard C<version> class with version
-modification operations, which can be useful in distribution release tools.
+C<Version::Dotted> and its subclasses complement standard C<version> class with bump operation and
+(re)define trial versions differently.
 
 This is C<Version::Dotted::Semantic> module/class documentation. However, read
 C<Version::Dotted> module/class documentation first, since it contains many relevant details.
@@ -459,7 +480,7 @@ C<Version::Dotted> module/class documentation first, since it contains many rele
 General topics like getting source, building, installing, bug reporting and some
 others are covered in the F<README>.
 
-=for test_synopsis my ( $v, $int );
+=for test_synopsis my ( $v, $int, $bool );
 
 =head1 SYNOPSIS
 
@@ -468,8 +489,8 @@ others are covered in the F<README>.
 
     # Construct:
     $v = Version::Dotted::Semantic->new( v1 );  # v1.0.0 (at least 3 parts)
-    $v = qv( v1 );                  # v1.0.0 (at least 3 parts)
-    $v = qv( 'v1.2.3.4' );          # v1.2.3.4
+    $v = qv( v1 );                              # ditto
+    $v = qv( 'v1.2.3.4' );                      # v1.2.3.4
 
     # Get parts by name (indexing also works):
     $int = $v->part( 'major' );     # Always defined.
@@ -481,18 +502,16 @@ others are covered in the F<README>.
     $int = $v->patch;       # ditto
     $int = $v->trial;       # May be undefined.
 
-    # Bump the version by name (indexing also works):
+    # Bump the version (indexing also works):
     $v->bump( 'trial' );    # Bump trial part.
     $v->bump( 'patch' );    # Bump patch and drop trial.
     $v->bump( 'minor' );    # Bump minor, reset patch and drop trial.
     $v->bump( 'major' );    # Bump major, reset minor and patch, drop trial.
 
     # Release status:
-    if ( $v->is_trial ) {   # If version has more than 3 parts.
-        ...
-    };
+    $bool = $v->is_trial;   # true if version has more than 3 parts.
 
-    # Other methods are inherited from Version::Dotted.
+    # See Version::Dotted for other methods.
 
 =head1 DESCRIPTION
 
@@ -512,12 +531,12 @@ Version object always has at least 3 parts.
 
 =item *
 
-First four parts have individual names:
+First four parts have individual names.
 
-    $v->part( 0 ) == $v->part( 'major' ) == $v->major;
-    $v->part( 1 ) == $v->part( 'minor' ) == $v->minor;
-    $v->part( 2 ) == $v->part( 'patch' ) == $v->patch;
-    $v->part( 3 ) == $v->part( 'trial' ) == $v->trial;
+    $v->major = $v->part( 'major' );    # == $v->part( 0 );
+    $v->minor = $v->part( 'minor' );    # == $v->part( 1 );
+    $v->patch = $v->part( 'patch' );    # == $v->part( 2 );
+    $v->trial = $v->part( 'trial' );    # == $v->part( 3 );
 
     $v->bump( 'trial' );  # the same as $v->bump( 3 );
 
@@ -532,6 +551,16 @@ The number of parts defines release status: more than 3 parts denotes trial rele
 
 =back
 
+=head1 CLASS ATTRIBUTES
+
+=head2 min_len
+
+Minimal number of parts, read-only.
+
+    $int = Version::Dotted::Semantic->min_len;  # == 3
+
+C<Version::Dotted::Semantic> objects always have at least 3 parts.
+
 =head1 OBJECT METHODS
 
 =head2 major
@@ -540,11 +569,11 @@ The number of parts defines release status: more than 3 parts denotes trial rele
 
 =head2 patch
 
-Returns the first, second, and third part of the version, respectively.
+Returns the first, the second, and the third part of the version, respectively.
 
-    $v->major;  # the first part
-    $v->minor;  # the second part
-    $v->patch;  # the third part
+    $int = $v->major;   # the first part
+    $int = $v->minor;   # the second part
+    $int = $v->patch;   # the third part
 
 Since version always has at least 3 parts, these methods never return C<undef>.
 
@@ -552,29 +581,37 @@ Since version always has at least 3 parts, these methods never return C<undef>.
 
 Returns the fourth part of the version.
 
-    $v->trial;  # the fourth part
+    $int = $v->trial;   # the fourth part
 
 The method returns C<undef> if version has less than 4 parts.
 
 =head2 is_trial
 
-Returns true (C<1>) if version has more than 3 parts, and false (C<undef>) otherwise.
+Returns true in case of trial version, and false otherwise.
 
-If version has no more than 4 parts, C<is_trial> is equal to evaluating C<trial> in boolean
-context. However, if version has more than 4 parts, it is not always true:
+    $bool = $v->is_trial;
 
-    $v = Version::Dotted::Semantic( v1.2.3.0.5 );
-    $v->trial;      # false (0)
-    $v->is_trial;   # true
+A version is considered trial if it has more than 3 parts:
+
+    qv( v1.2.3.4 )->is_trial;   # true
+    qv( v1.2.4   )->is_trial;   # false
+
+=for comment ---------------------------------------------------------------------------------------
+
+=for comment ---------------------------------------------------------------------------------------
+
+=for comment ---------------------------------------------------------------------------------------
 
 =head1 SEMANTIC VERSIONING
 
 See L<Semantic Versioning 2.0.0|http://semver.org/spec/v2.0.0.html>. It sound very reasonable to
 me.
 
-Unfortunately, Semantic Versioning cannot be applied to Perl modules due to wider character set
-(letters, hyphens, plus signs, e. g. 1.0.0-alpha.3+8daebec8a8e1) and specific precedence rules
-(1.0.0-alpha < 1.0.0).
+Unfortunately, Semantic Versioning cannot be applied to Perl modules (maintaining compatibility
+with C<version> objects) due to wider character set (letters, hyphens, plus signs, e. g.
+1.0.0-alpha.3+8daebec8a8e1) and specific precedence rules (1.0.0-alpha < 1.0.0).
+
+=for comment ---------------------------------------------------------------------------------------
 
 =head1 DOTTED SEMANTIC VERSIONING
 
@@ -701,6 +738,8 @@ Semantic Versioning 2.0.0 for Perl modules.
 L<Semantic Versioning 2.0.0|http://semver.org/spec/v2.0.0.html> is authored by L<Tom
 Preston-Werner|http://tom.preston-werner.com/>, inventor of Gravatars and cofounder of GitHub.
 
+=for comment ---------------------------------------------------------------------------------------
+
 =head1 ADAPTATION DETAILS
 
 Paragraphs 1..8 of Semantic Versioning define I<normal> version number and establish rules for
